@@ -1,11 +1,6 @@
 package Bio::Tradis::Analysis::Exceptions;
 # ABSTRACT: Custom exceptions
-
-=head1 SYNOPSIS
-
-Basic exception catcher
-
-=cut
+$Bio::Tradis::Analysis::Exceptions::VERSION = '1.4.5';
 
 use Exception::Class (
     Bio::Tradis::Analysis::Exceptions::FailedToOpenAlignmentSlice => { description => 'Couldnt get reads from alignment slice. Error with Samtools or BAM' },
@@ -18,3 +13,35 @@ use Exception::Class (
 );
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Bio::Tradis::Analysis::Exceptions - Custom exceptions
+
+=head1 VERSION
+
+version 1.4.5
+
+=head1 SYNOPSIS
+
+Basic exception catcher
+
+=head1 AUTHOR
+
+Carla Cummins <path-help@sanger.ac.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Wellcome Trust Sanger Institute.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
+
+=cut
